function pR=estimateRecovered(C, D, kdays, tstart, tend)
%
% Estimation of Recovered from Confirmed and Deaths,
% Estimation of case fatality and case recovery rates
% This program does no smoothing.
% If smoothing is required, do it outside. 
% If used with a fixed backlog, use
% tstart=tend-backlog+1
%
% Input:
% 
% C, D : Confirmed and Deaths, same length
% kdays : number of days after which Confirmed 
% are assumed to be Recovered, for k-day rule
% if they do not die in between
% tstart, tend : range of data used
% Data of D between tstart-1 and tend are used
% Data of C between tstart-1-kdays and tend-1 are used 
% The linear system has tend-tstart+1 equations and kdays unknowns
% 
% Output:
% qopt : survival probability d days after Confirmation
% p : kdays-vector of probabilities p_j to die j days after Confirmation  
% R : estimated Recovered, same length as C and D
% pR: vector of the form [qopt; p; R]
%
if kdays > tend-tstart+1
    tdiffk=[tstart tend kdays]
    error('Not enough equations in estimateRecovered')
end 
global A % the matrix and right-hand side 
global rhs
%
dD=zeros(size(D)); % vector for daily deaths
dC=zeros(size(C)); % daily Confirmed
Clen=length(C);
% daily values at day i are stored in i-th position
dD(2:Clen)=D(2:Clen)-D(1:Clen-1); 
dC(2:Clen)=C(2:Clen)-C(1:Clen-1); 
% we use deaths data between tstart-1 and tend 
rhs=dD(tstart:tend); % D_n-D_{n-1} 
A=zeros(tend-tstart+1,kdays); % the data matrix
for j=1:kdays  % form the dC shifts as rows
    A(:,j)=dC(tstart-j:tend-j);  
end
B=ones(kdays,1);
p0=zeros(kdays,1); % starting at zero, and lower bounds
options=optimset('MaxFunEvals',50000,'MaxIter',10000);
% perform nonlinear least squares
popt=lsqnonlin(@myfun,p0,p0,B,options);
% recalculate data at optimum 
% fopt=myfun(popt);
qq=1;
for j=1:kdays
    qq=qq*(1-popt(j));
end
pd=qq; % the survival rate
% now calculate daily Recovered
dR=pd*dC(1:Clen-kdays);
% and insert into full R vector
R=zeros(size(C));
for j=2:Clen-kdays
    R(j+kdays)=R(j-1+kdays)+dR(j-1);
end
R=floor(R);
pR=[pd; popt; R];
% something on error evaluation 
% sum=rhs;
% qopt=p2q(popt);
% for j=1:kdays
%     sum=sum-qopt(j)*dC(tstart-j:tend-j);
% end
% [max(abs(sum)) norm(sum)/sqrt(length(sum))] 
% fopt
% pause

function f=myfun(p)
% the internal function for lsqnonlin
global A % the matrix and right-hand side 
global rhs
% we convert p to q
q=p2q(p);
% the vector of data to be minimized
f=[rhs-A*q; 100000*max(0,sum(p)-1)];
return

function q=p2q(p)
% convert p to q
q=zeros(size(p));
q(1)=1-p(1);
for k=2:length(p)
    q(k)=q(k-1)*(1-p(k));
end
% now the q are the products of the 1-p_j
% then put in p(k) backwards
for k=length(p):-1:2
    q(k)=q(k-1)*p(k);
end
q(1)=p(1);
