function SMHCIRD=runSMHCIRD(SMHCIRDstart, gIF, gCR, gCD, gCF, N, beta, gamma, timespan)
%
% runs the full model (hidden: SMH, Johns Hopkins: C=I-R-D, R, D) with variables:
%
% S = Susceptibles, 
% M = unregistered Infectious, the I in the hidden SIR model
% H = unregistered Recovered, part of the R in the hidden SIR model
% C = Confirmed, cumulative, like in Johns Hopkins data
% I = confirmed Infectious, I=C-R-D, not cumulative 
% R = confirmed Recovered, like in Johns Hopkins data, cumulative
% D = confirmed deaths, like in Johns Hopkins data, cumulative
% HC= H+C, cumulative, the R in the hidden SIR model
%
% SMHCIRDstart : starting vector of values in the SMHCIRD order
% The model runs from these values on, and does NOT use backwards data.
% gIF, gCR, gCD, gCF : constants like the gamma in the paper
% N : population size, 
% beta, gamma: like in any other SIR model
% timespan : the calculation runs from 1 to timespan
% 
% Output: a matrix with columns S, M, H, C, I, R, D 
% each column vector of length timespan
%
% Note that the model runs unconditionally,
% i.e. it might run into negative values for the variables.
% 
S=zeros(timespan,1);
M=zeros(timespan,1);
H=zeros(timespan,1);
C=zeros(timespan,1);
I=zeros(timespan,1);
R=zeros(timespan,1);
D=zeros(timespan,1);
HC=zeros(timespan,1); % for H+C 
% initialize startup 
S(1,1)=SMHCIRDstart(1);
M(1,1)=SMHCIRDstart(2);
H(1,1)=SMHCIRDstart(3);
C(1,1)=SMHCIRDstart(4);
I(1,1)=SMHCIRDstart(5);
R(1,1)=SMHCIRDstart(6);
D(1,1)=SMHCIRDstart(7);
HC(1,1)=H(1,1)+C(1,1);
% run the model, as in the paper
for i=1:timespan-1
    S(i+1,1) =S(i,1)  -beta*(S(i,1)/N)*M(i,1);
    M(i+1,1) =M(i,1)  +beta*(S(i,1)/N)*M(i,1)-gamma*M(i,1);
    HC(i+1,1)=HC(i,1) +gamma*M(i,1);
    C(i+1,1) =C(i,1)  +gIF*(S(i,1)-S(i+1,1))/gCF;
    R(i+1,1) =R(i,1)  +gCR*I(i,1);
    D(i+1,1) =D(i,1)  +gCD*I(i,1);
    I(i+1,1) =C(i+1,1)-R(i+1,1)-D(i+1,1);
end
H=HC-C;
% assemble final output matrix
SMHCIRD=[S M H C I R D];
